Module tcp

Module tcp 

Network systems implementation backed by the TCP network protocol.

Structs

TcpConnectionListenerSystem
System to listen for incoming connections and cache them to the resource.
TcpNetworkBundle
Use this network bundle to add the TCP transport layer to your game.
TcpNetworkRecvSystem
System to receive messages from all open TcpStreams.
TcpNetworkResource
TcpNetworkSendSystem
System to send messages to a particular open TcpStream.
TcpStreamManagementSystem
System to manage the current active TCPStreams.